@@ -72,7 +72,9 @@ class AcceptanceRateFixer(ORFixer):
         return painrating
 
     def rate(self, rating: EntityRating):
-        return self.getRating(rating.getRecord())
+        aRating = self.getRating(rating.getRecord())
+        rating.set(pain=aRating.pain, reason=aRating.reason, hint=aRating.hint)
+        return rating
         
 if __name__ == '__main__':
     PageFixerManager.runCmdLine([AcceptanceRateFixer])
\ No newline at end of file
