@@ -4,7 +4,7 @@ Created on 2021-04-16
 @author: wf
 '''
 from ormigrate.smw.pagefixer import PageFixerManager
-from ormigrate.fixer import ORFixer
+from ormigrate.fixer import ORFixer, Entity
 from ormigrate.smw.rating import Rating, RatingType, EntityRating
 
 
@@ -15,14 +15,18 @@ class EventSeriesProvenanceFixer(ORFixer):
     issue="https://github.com/SmartDataAnalytics/OpenResearch/issues/57"
     purpose="fixes missing provenance information"
 
+    worksOn = [Entity.EVENT_SERIES]
+
     def __init__(self,pageFixerManager):
         '''
         Constructor
         '''
-        super(EventSeriesProvenanceFixer, self).__init__(pageFixerManager)
+        super().__init__(pageFixerManager)
 
     def rate(self, rating: EntityRating):
-        return self.getRating(rating.getRecord())
+        aRating = self.getRating(rating.getRecord())
+        rating.set(pain=aRating.pain, reason=aRating.reason, hint=aRating.hint)
+        return rating
         
     @classmethod
     def getRating(cls,eventRecord):
@@ -39,3 +43,5 @@ class EventSeriesProvenanceFixer(ORFixer):
             return Rating(3,RatingType.ok,'Wikidata only series')
         return Rating(7,RatingType.invalid,'Series provenance data missing')
     
+if __name__ == '__main__':
+    PageFixerManager.runCmdLine([EventSeriesProvenanceFixer])
